# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.historic_activity_instance_api import HistoricActivityInstanceApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestHistoricActivityInstanceApi(unittest.TestCase):
    """HistoricActivityInstanceApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.historic_activity_instance_api.HistoricActivityInstanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_historic_activity_instance(self):
        """Test case for get_historic_activity_instance

        Get  # noqa: E501
        """
        pass

    def test_get_historic_activity_instances(self):
        """Test case for get_historic_activity_instances

        Get List  # noqa: E501
        """
        pass

    def test_get_historic_activity_instances_count(self):
        """Test case for get_historic_activity_instances_count

        Get List Count  # noqa: E501
        """
        pass

    def test_query_historic_activity_instances(self):
        """Test case for query_historic_activity_instances

        Get List (POST)  # noqa: E501
        """
        pass

    def test_query_historic_activity_instances_count(self):
        """Test case for query_historic_activity_instances_count

        Get List Count (POST)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
