# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class VariableQueryParameterDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'operator': 'str',
        'value': 'object'
    }

    attribute_map = {
        'name': 'name',
        'operator': 'operator',
        'value': 'value'
    }

    def __init__(self, name=None, operator=None, value=None, local_vars_configuration=None):  # noqa: E501
        """VariableQueryParameterDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._operator = None
        self._value = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if operator is not None:
            self.operator = operator
        if value is not None:
            self.value = value

    @property
    def name(self):
        """Gets the name of this VariableQueryParameterDto.  # noqa: E501

        Variable name  # noqa: E501

        :return: The name of this VariableQueryParameterDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this VariableQueryParameterDto.

        Variable name  # noqa: E501

        :param name: The name of this VariableQueryParameterDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def operator(self):
        """Gets the operator of this VariableQueryParameterDto.  # noqa: E501

        Comparison operator to be used  # noqa: E501

        :return: The operator of this VariableQueryParameterDto.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this VariableQueryParameterDto.

        Comparison operator to be used  # noqa: E501

        :param operator: The operator of this VariableQueryParameterDto.  # noqa: E501
        :type: str
        """
        allowed_values = ["eq", "neq", "gt", "gteq", "lt", "lteq", "like"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `operator` ({0}), must be one of {1}"  # noqa: E501
                .format(operator, allowed_values)
            )

        self._operator = operator

    @property
    def value(self):
        """Gets the value of this VariableQueryParameterDto.  # noqa: E501

        The variable value, could be of type boolean, string or number  # noqa: E501

        :return: The value of this VariableQueryParameterDto.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this VariableQueryParameterDto.

        The variable value, could be of type boolean, string or number  # noqa: E501

        :param value: The value of this VariableQueryParameterDto.  # noqa: E501
        :type: object
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VariableQueryParameterDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VariableQueryParameterDto):
            return True

        return self.to_dict() != other.to_dict()
