# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class DeleteProcessInstancesDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'process_instance_ids': 'list[str]',
        'delete_reason': 'str',
        'skip_custom_listeners': 'bool',
        'skip_subprocesses': 'bool',
        'process_instance_query': 'ProcessInstanceQueryDto',
        'historic_process_instance_query': 'HistoricProcessInstanceQueryDto'
    }

    attribute_map = {
        'process_instance_ids': 'processInstanceIds',
        'delete_reason': 'deleteReason',
        'skip_custom_listeners': 'skipCustomListeners',
        'skip_subprocesses': 'skipSubprocesses',
        'process_instance_query': 'processInstanceQuery',
        'historic_process_instance_query': 'historicProcessInstanceQuery'
    }

    def __init__(self, process_instance_ids=None, delete_reason=None, skip_custom_listeners=None, skip_subprocesses=None, process_instance_query=None, historic_process_instance_query=None, local_vars_configuration=None):  # noqa: E501
        """DeleteProcessInstancesDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._process_instance_ids = None
        self._delete_reason = None
        self._skip_custom_listeners = None
        self._skip_subprocesses = None
        self._process_instance_query = None
        self._historic_process_instance_query = None
        self.discriminator = None

        if process_instance_ids is not None:
            self.process_instance_ids = process_instance_ids
        if delete_reason is not None:
            self.delete_reason = delete_reason
        self.skip_custom_listeners = skip_custom_listeners
        self.skip_subprocesses = skip_subprocesses
        if process_instance_query is not None:
            self.process_instance_query = process_instance_query
        if historic_process_instance_query is not None:
            self.historic_process_instance_query = historic_process_instance_query

    @property
    def process_instance_ids(self):
        """Gets the process_instance_ids of this DeleteProcessInstancesDto.  # noqa: E501

        A list process instance ids to delete.  # noqa: E501

        :return: The process_instance_ids of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._process_instance_ids

    @process_instance_ids.setter
    def process_instance_ids(self, process_instance_ids):
        """Sets the process_instance_ids of this DeleteProcessInstancesDto.

        A list process instance ids to delete.  # noqa: E501

        :param process_instance_ids: The process_instance_ids of this DeleteProcessInstancesDto.  # noqa: E501
        :type: list[str]
        """

        self._process_instance_ids = process_instance_ids

    @property
    def delete_reason(self):
        """Gets the delete_reason of this DeleteProcessInstancesDto.  # noqa: E501

        A string with delete reason.  # noqa: E501

        :return: The delete_reason of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: str
        """
        return self._delete_reason

    @delete_reason.setter
    def delete_reason(self, delete_reason):
        """Sets the delete_reason of this DeleteProcessInstancesDto.

        A string with delete reason.  # noqa: E501

        :param delete_reason: The delete_reason of this DeleteProcessInstancesDto.  # noqa: E501
        :type: str
        """

        self._delete_reason = delete_reason

    @property
    def skip_custom_listeners(self):
        """Gets the skip_custom_listeners of this DeleteProcessInstancesDto.  # noqa: E501

        Skip execution listener invocation for activities that are started or ended as part of this request.  # noqa: E501

        :return: The skip_custom_listeners of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_custom_listeners

    @skip_custom_listeners.setter
    def skip_custom_listeners(self, skip_custom_listeners):
        """Sets the skip_custom_listeners of this DeleteProcessInstancesDto.

        Skip execution listener invocation for activities that are started or ended as part of this request.  # noqa: E501

        :param skip_custom_listeners: The skip_custom_listeners of this DeleteProcessInstancesDto.  # noqa: E501
        :type: bool
        """

        self._skip_custom_listeners = skip_custom_listeners

    @property
    def skip_subprocesses(self):
        """Gets the skip_subprocesses of this DeleteProcessInstancesDto.  # noqa: E501

        Skip deletion of the subprocesses related to deleted processes as part of this request.  # noqa: E501

        :return: The skip_subprocesses of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_subprocesses

    @skip_subprocesses.setter
    def skip_subprocesses(self, skip_subprocesses):
        """Sets the skip_subprocesses of this DeleteProcessInstancesDto.

        Skip deletion of the subprocesses related to deleted processes as part of this request.  # noqa: E501

        :param skip_subprocesses: The skip_subprocesses of this DeleteProcessInstancesDto.  # noqa: E501
        :type: bool
        """

        self._skip_subprocesses = skip_subprocesses

    @property
    def process_instance_query(self):
        """Gets the process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501


        :return: The process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: ProcessInstanceQueryDto
        """
        return self._process_instance_query

    @process_instance_query.setter
    def process_instance_query(self, process_instance_query):
        """Sets the process_instance_query of this DeleteProcessInstancesDto.


        :param process_instance_query: The process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501
        :type: ProcessInstanceQueryDto
        """

        self._process_instance_query = process_instance_query

    @property
    def historic_process_instance_query(self):
        """Gets the historic_process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501


        :return: The historic_process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501
        :rtype: HistoricProcessInstanceQueryDto
        """
        return self._historic_process_instance_query

    @historic_process_instance_query.setter
    def historic_process_instance_query(self, historic_process_instance_query):
        """Sets the historic_process_instance_query of this DeleteProcessInstancesDto.


        :param historic_process_instance_query: The historic_process_instance_query of this DeleteProcessInstancesDto.  # noqa: E501
        :type: HistoricProcessInstanceQueryDto
        """

        self._historic_process_instance_query = historic_process_instance_query

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteProcessInstancesDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeleteProcessInstancesDto):
            return True

        return self.to_dict() != other.to_dict()
