# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class SetRemovalTimeToHistoricProcessInstancesDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'historic_process_instance_ids': 'list[str]',
        'historic_process_instance_query': 'HistoricProcessInstanceQueryDto',
        'hierarchical': 'bool',
        'absolute_removal_time': 'datetime',
        'cleared_removal_time': 'bool',
        'calculated_removal_time': 'bool'
    }

    attribute_map = {
        'historic_process_instance_ids': 'historicProcessInstanceIds',
        'historic_process_instance_query': 'historicProcessInstanceQuery',
        'hierarchical': 'hierarchical',
        'absolute_removal_time': 'absoluteRemovalTime',
        'cleared_removal_time': 'clearedRemovalTime',
        'calculated_removal_time': 'calculatedRemovalTime'
    }

    def __init__(self, historic_process_instance_ids=None, historic_process_instance_query=None, hierarchical=None, absolute_removal_time=None, cleared_removal_time=None, calculated_removal_time=None, local_vars_configuration=None):  # noqa: E501
        """SetRemovalTimeToHistoricProcessInstancesDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._historic_process_instance_ids = None
        self._historic_process_instance_query = None
        self._hierarchical = None
        self._absolute_removal_time = None
        self._cleared_removal_time = None
        self._calculated_removal_time = None
        self.discriminator = None

        if historic_process_instance_ids is not None:
            self.historic_process_instance_ids = historic_process_instance_ids
        if historic_process_instance_query is not None:
            self.historic_process_instance_query = historic_process_instance_query
        self.hierarchical = hierarchical
        self.absolute_removal_time = absolute_removal_time
        self.cleared_removal_time = cleared_removal_time
        self.calculated_removal_time = calculated_removal_time

    @property
    def historic_process_instance_ids(self):
        """Gets the historic_process_instance_ids of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501

        The id of the process instance.  # noqa: E501

        :return: The historic_process_instance_ids of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :rtype: list[str]
        """
        return self._historic_process_instance_ids

    @historic_process_instance_ids.setter
    def historic_process_instance_ids(self, historic_process_instance_ids):
        """Sets the historic_process_instance_ids of this SetRemovalTimeToHistoricProcessInstancesDto.

        The id of the process instance.  # noqa: E501

        :param historic_process_instance_ids: The historic_process_instance_ids of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :type: list[str]
        """

        self._historic_process_instance_ids = historic_process_instance_ids

    @property
    def historic_process_instance_query(self):
        """Gets the historic_process_instance_query of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501


        :return: The historic_process_instance_query of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :rtype: HistoricProcessInstanceQueryDto
        """
        return self._historic_process_instance_query

    @historic_process_instance_query.setter
    def historic_process_instance_query(self, historic_process_instance_query):
        """Sets the historic_process_instance_query of this SetRemovalTimeToHistoricProcessInstancesDto.


        :param historic_process_instance_query: The historic_process_instance_query of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :type: HistoricProcessInstanceQueryDto
        """

        self._historic_process_instance_query = historic_process_instance_query

    @property
    def hierarchical(self):
        """Gets the hierarchical of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501

        Sets the removal time to all historic process instances in the hierarchy. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :return: The hierarchical of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :rtype: bool
        """
        return self._hierarchical

    @hierarchical.setter
    def hierarchical(self, hierarchical):
        """Sets the hierarchical of this SetRemovalTimeToHistoricProcessInstancesDto.

        Sets the removal time to all historic process instances in the hierarchy. Value may only be `true`, as `false` is the default behavior.  # noqa: E501

        :param hierarchical: The hierarchical of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :type: bool
        """

        self._hierarchical = hierarchical

    @property
    def absolute_removal_time(self):
        """Gets the absolute_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501

        The date for which the instances shall be removed. Value may not be `null`.  **Note:** Cannot be set in conjunction with `clearedRemovalTime` or `calculatedRemovalTime`.  # noqa: E501

        :return: The absolute_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :rtype: datetime
        """
        return self._absolute_removal_time

    @absolute_removal_time.setter
    def absolute_removal_time(self, absolute_removal_time):
        """Sets the absolute_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.

        The date for which the instances shall be removed. Value may not be `null`.  **Note:** Cannot be set in conjunction with `clearedRemovalTime` or `calculatedRemovalTime`.  # noqa: E501

        :param absolute_removal_time: The absolute_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :type: datetime
        """

        self._absolute_removal_time = absolute_removal_time

    @property
    def cleared_removal_time(self):
        """Gets the cleared_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501

        Sets the removal time to `null`. Value may only be `true`, as `false` is the default behavior.  **Note:** Cannot be set in conjunction with `absoluteRemovalTime` or `calculatedRemovalTime`.  # noqa: E501

        :return: The cleared_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :rtype: bool
        """
        return self._cleared_removal_time

    @cleared_removal_time.setter
    def cleared_removal_time(self, cleared_removal_time):
        """Sets the cleared_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.

        Sets the removal time to `null`. Value may only be `true`, as `false` is the default behavior.  **Note:** Cannot be set in conjunction with `absoluteRemovalTime` or `calculatedRemovalTime`.  # noqa: E501

        :param cleared_removal_time: The cleared_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :type: bool
        """

        self._cleared_removal_time = cleared_removal_time

    @property
    def calculated_removal_time(self):
        """Gets the calculated_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501

        The removal time is calculated based on the engine's configuration settings. Value may only be `true`, as `false` is the default behavior.  **Note:** Cannot be set in conjunction with `absoluteRemovalTime` or `clearedRemovalTime`.  # noqa: E501

        :return: The calculated_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :rtype: bool
        """
        return self._calculated_removal_time

    @calculated_removal_time.setter
    def calculated_removal_time(self, calculated_removal_time):
        """Sets the calculated_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.

        The removal time is calculated based on the engine's configuration settings. Value may only be `true`, as `false` is the default behavior.  **Note:** Cannot be set in conjunction with `absoluteRemovalTime` or `clearedRemovalTime`.  # noqa: E501

        :param calculated_removal_time: The calculated_removal_time of this SetRemovalTimeToHistoricProcessInstancesDto.  # noqa: E501
        :type: bool
        """

        self._calculated_removal_time = calculated_removal_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SetRemovalTimeToHistoricProcessInstancesDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SetRemovalTimeToHistoricProcessInstancesDto):
            return True

        return self.to_dict() != other.to_dict()
