# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.deployment_api import DeploymentApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestDeploymentApi(unittest.TestCase):
    """DeploymentApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.deployment_api.DeploymentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_deployment(self):
        """Test case for create_deployment

        """
        pass

    def test_delete_deployment(self):
        """Test case for delete_deployment

        """
        pass

    def test_get_deployment(self):
        """Test case for get_deployment

        """
        pass

    def test_get_deployment_resource(self):
        """Test case for get_deployment_resource

        """
        pass

    def test_get_deployment_resource_data(self):
        """Test case for get_deployment_resource_data

        """
        pass

    def test_get_deployment_resources(self):
        """Test case for get_deployment_resources

        """
        pass

    def test_get_deployments(self):
        """Test case for get_deployments

        """
        pass

    def test_get_deployments_count(self):
        """Test case for get_deployments_count

        """
        pass

    def test_redeploy(self):
        """Test case for redeploy

        """
        pass


if __name__ == '__main__':
    unittest.main()
