# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.telemetry_api import TelemetryApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestTelemetryApi(unittest.TestCase):
    """TelemetryApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.telemetry_api.TelemetryApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_configure_telemetry(self):
        """Test case for configure_telemetry

        Configure Telemetry  # noqa: E501
        """
        pass

    def test_get_telemetry_configuration(self):
        """Test case for get_telemetry_configuration

        Fetch Telemetry Configuration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
