# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.historic_process_instance_api import HistoricProcessInstanceApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestHistoricProcessInstanceApi(unittest.TestCase):
    """HistoricProcessInstanceApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.historic_process_instance_api.HistoricProcessInstanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_historic_process_instance(self):
        """Test case for delete_historic_process_instance

        Delete  # noqa: E501
        """
        pass

    def test_delete_historic_process_instances_async(self):
        """Test case for delete_historic_process_instances_async

        Delete Async (POST)  # noqa: E501
        """
        pass

    def test_delete_historic_variable_instances_of_historic_process_instance(self):
        """Test case for delete_historic_variable_instances_of_historic_process_instance

        Delete Variable Instances  # noqa: E501
        """
        pass

    def test_get_historic_process_instance(self):
        """Test case for get_historic_process_instance

        Get  # noqa: E501
        """
        pass

    def test_get_historic_process_instance_duration_report(self):
        """Test case for get_historic_process_instance_duration_report

        Get Duration Report  # noqa: E501
        """
        pass

    def test_get_historic_process_instances(self):
        """Test case for get_historic_process_instances

        Get List  # noqa: E501
        """
        pass

    def test_get_historic_process_instances_count(self):
        """Test case for get_historic_process_instances_count

        Get List Count  # noqa: E501
        """
        pass

    def test_query_historic_process_instances(self):
        """Test case for query_historic_process_instances

        Get List (POST)  # noqa: E501
        """
        pass

    def test_query_historic_process_instances_count(self):
        """Test case for query_historic_process_instances_count

        Get List Count (POST)  # noqa: E501
        """
        pass

    def test_set_removal_time_async(self):
        """Test case for set_removal_time_async

        Set Removal Time Async (POST)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
