# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.historic_activity_instance_dto import HistoricActivityInstanceDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestHistoricActivityInstanceDto(unittest.TestCase):
    """HistoricActivityInstanceDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test HistoricActivityInstanceDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.historic_activity_instance_dto.HistoricActivityInstanceDto()  # noqa: E501
        if include_optional :
            return HistoricActivityInstanceDto(
                id = '0', 
                parent_activity_instance_id = '0', 
                activity_id = '0', 
                activity_name = '0', 
                activity_type = '0', 
                process_definition_key = '0', 
                process_definition_id = '0', 
                process_instance_id = '0', 
                execution_id = '0', 
                task_id = '0', 
                assignee = '0', 
                called_process_instance_id = '0', 
                called_case_instance_id = '0', 
                start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                duration_in_millis = 56, 
                canceled = True, 
                complete_scope = True, 
                tenant_id = '0', 
                removal_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                root_process_instance_id = '0'
            )
        else :
            return HistoricActivityInstanceDto(
        )

    def testHistoricActivityInstanceDto(self):
        """Test HistoricActivityInstanceDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
