# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.process_instance_query_dto import ProcessInstanceQueryDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestProcessInstanceQueryDto(unittest.TestCase):
    """ProcessInstanceQueryDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProcessInstanceQueryDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.process_instance_query_dto.ProcessInstanceQueryDto()  # noqa: E501
        if include_optional :
            return ProcessInstanceQueryDto(
                deployment_id = '0', 
                process_definition_id = '0', 
                process_definition_key = '0', 
                process_definition_key_in = [
                    '0'
                    ], 
                process_definition_key_not_in = [
                    '0'
                    ], 
                business_key = '0', 
                business_key_like = '0', 
                case_instance_id = '0', 
                super_process_instance = '0', 
                sub_process_instance = '0', 
                super_case_instance = '0', 
                sub_case_instance = '0', 
                active = True, 
                suspended = True, 
                process_instance_ids = [
                    '0'
                    ], 
                with_incident = True, 
                incident_id = '0', 
                incident_type = '0', 
                incident_message = '0', 
                incident_message_like = '0', 
                tenant_id_in = [
                    '0'
                    ], 
                without_tenant_id = True, 
                process_definition_without_tenant_id = True, 
                activity_id_in = [
                    '0'
                    ], 
                root_process_instances = True, 
                leaf_process_instances = True, 
                variables = [
                    generic_camunda_client.models.variable_query_parameter_dto.VariableQueryParameterDto(
                        name = '0', 
                        operator = 'eq', 
                        value = generic_camunda_client.models.value.value(), )
                    ], 
                variable_names_ignore_case = True, 
                variable_values_ignore_case = True, 
                or_queries = [
                    generic_camunda_client.models.process_instance_query_dto.ProcessInstanceQueryDto(
                        deployment_id = '0', 
                        process_definition_id = '0', 
                        process_definition_key = '0', 
                        process_definition_key_in = [
                            '0'
                            ], 
                        process_definition_key_not_in = [
                            '0'
                            ], 
                        business_key = '0', 
                        business_key_like = '0', 
                        case_instance_id = '0', 
                        super_process_instance = '0', 
                        sub_process_instance = '0', 
                        super_case_instance = '0', 
                        sub_case_instance = '0', 
                        active = True, 
                        suspended = True, 
                        process_instance_ids = [
                            '0'
                            ], 
                        with_incident = True, 
                        incident_id = '0', 
                        incident_type = '0', 
                        incident_message = '0', 
                        incident_message_like = '0', 
                        tenant_id_in = [
                            '0'
                            ], 
                        without_tenant_id = True, 
                        process_definition_without_tenant_id = True, 
                        activity_id_in = [
                            '0'
                            ], 
                        root_process_instances = True, 
                        leaf_process_instances = True, 
                        variables = [
                            generic_camunda_client.models.variable_query_parameter_dto.VariableQueryParameterDto(
                                name = '0', 
                                operator = 'eq', 
                                value = generic_camunda_client.models.value.value(), )
                            ], 
                        variable_names_ignore_case = True, 
                        variable_values_ignore_case = True, 
                        sorting = [
                            generic_camunda_client.models.process_instance_query_dto_sorting.ProcessInstanceQueryDto_sorting(
                                sort_by = 'instanceId', 
                                sort_order = 'asc', )
                            ], )
                    ], 
                sorting = [
                    generic_camunda_client.models.process_instance_query_dto_sorting.ProcessInstanceQueryDto_sorting(
                        sort_by = 'instanceId', 
                        sort_order = 'asc', )
                    ]
            )
        else :
            return ProcessInstanceQueryDto(
        )

    def testProcessInstanceQueryDto(self):
        """Test ProcessInstanceQueryDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
