# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.task_identity_link_api import TaskIdentityLinkApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestTaskIdentityLinkApi(unittest.TestCase):
    """TaskIdentityLinkApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.task_identity_link_api.TaskIdentityLinkApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_identity_link(self):
        """Test case for add_identity_link

        """
        pass

    def test_delete_identity_link(self):
        """Test case for delete_identity_link

        """
        pass

    def test_get_identity_links(self):
        """Test case for get_identity_links

        """
        pass


if __name__ == '__main__':
    unittest.main()
