# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.activity_instance_dto import ActivityInstanceDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestActivityInstanceDto(unittest.TestCase):
    """ActivityInstanceDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ActivityInstanceDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.activity_instance_dto.ActivityInstanceDto()  # noqa: E501
        if include_optional :
            return ActivityInstanceDto(
                id = '0', 
                parent_activity_instance_id = '0', 
                activity_id = '0', 
                activity_name = '0', 
                activity_type = '0', 
                process_instance_id = '0', 
                process_definition_id = '0', 
                child_activity_instances = [
                    generic_camunda_client.models.activity_instance_dto.ActivityInstanceDto(
                        id = '0', 
                        parent_activity_instance_id = '0', 
                        activity_id = '0', 
                        activity_name = '0', 
                        activity_type = '0', 
                        process_instance_id = '0', 
                        process_definition_id = '0', 
                        child_activity_instances = [
                            generic_camunda_client.models.activity_instance_dto.ActivityInstanceDto(
                                id = '0', 
                                parent_activity_instance_id = '0', 
                                activity_id = '0', 
                                activity_name = '0', 
                                activity_type = '0', 
                                process_instance_id = '0', 
                                process_definition_id = '0', 
                                child_transition_instances = [
                                    generic_camunda_client.models.transition_instance_dto.TransitionInstanceDto(
                                        id = '0', 
                                        parent_activity_instance_id = '0', 
                                        activity_id = '0', 
                                        activity_name = '0', 
                                        activity_type = '0', 
                                        process_instance_id = '0', 
                                        process_definition_id = '0', 
                                        execution_id = '0', 
                                        incident_ids = [
                                            '0'
                                            ], 
                                        incidents = [
                                            generic_camunda_client.models.activity_instance_incident_dto.ActivityInstanceIncidentDto(
                                                id = '0', 
                                                parent_activity_instance_id = '0', )
                                            ], )
                                    ], 
                                execution_ids = [
                                    '0'
                                    ], 
                                incident_ids = [
                                    '0'
                                    ], 
                                incidents = [
                                    generic_camunda_client.models.activity_instance_incident_dto.ActivityInstanceIncidentDto(
                                        id = '0', 
                                        parent_activity_instance_id = '0', )
                                    ], )
                            ], 
                        child_transition_instances = [
                            generic_camunda_client.models.transition_instance_dto.TransitionInstanceDto(
                                id = '0', 
                                parent_activity_instance_id = '0', 
                                activity_id = '0', 
                                activity_name = '0', 
                                activity_type = '0', 
                                process_instance_id = '0', 
                                process_definition_id = '0', 
                                execution_id = '0', )
                            ], 
                        execution_ids = [
                            '0'
                            ], 
                        incident_ids = [
                            '0'
                            ], 
                        incidents = [
                            generic_camunda_client.models.activity_instance_incident_dto.ActivityInstanceIncidentDto(
                                id = '0', 
                                parent_activity_instance_id = '0', )
                            ], )
                    ], 
                child_transition_instances = [
                    generic_camunda_client.models.transition_instance_dto.TransitionInstanceDto(
                        id = '0', 
                        parent_activity_instance_id = '0', 
                        activity_id = '0', 
                        activity_name = '0', 
                        activity_type = '0', 
                        process_instance_id = '0', 
                        process_definition_id = '0', 
                        execution_id = '0', 
                        incident_ids = [
                            '0'
                            ], 
                        incidents = [
                            generic_camunda_client.models.activity_instance_incident_dto.ActivityInstanceIncidentDto(
                                id = '0', 
                                parent_activity_instance_id = '0', )
                            ], )
                    ], 
                execution_ids = [
                    '0'
                    ], 
                incident_ids = [
                    '0'
                    ], 
                incidents = [
                    generic_camunda_client.models.activity_instance_incident_dto.ActivityInstanceIncidentDto(
                        id = '0', 
                        parent_activity_instance_id = '0', )
                    ]
            )
        else :
            return ActivityInstanceDto(
        )

    def testActivityInstanceDto(self):
        """Test ActivityInstanceDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
