# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class IdentityLinkDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'group_id': 'str',
        'type': 'str'
    }

    attribute_map = {
        'user_id': 'userId',
        'group_id': 'groupId',
        'type': 'type'
    }

    def __init__(self, user_id=None, group_id=None, type=None, local_vars_configuration=None):  # noqa: E501
        """IdentityLinkDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._group_id = None
        self._type = None
        self.discriminator = None

        if user_id is not None:
            self.user_id = user_id
        if group_id is not None:
            self.group_id = group_id
        self.type = type

    @property
    def user_id(self):
        """Gets the user_id of this IdentityLinkDto.  # noqa: E501

        The id of the user participating in this link. Either `userId` or `groupId` is set.  # noqa: E501

        :return: The user_id of this IdentityLinkDto.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this IdentityLinkDto.

        The id of the user participating in this link. Either `userId` or `groupId` is set.  # noqa: E501

        :param user_id: The user_id of this IdentityLinkDto.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def group_id(self):
        """Gets the group_id of this IdentityLinkDto.  # noqa: E501

        The id of the group participating in this link. Either `groupId` or `userId` is set.  # noqa: E501

        :return: The group_id of this IdentityLinkDto.  # noqa: E501
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this IdentityLinkDto.

        The id of the group participating in this link. Either `groupId` or `userId` is set.  # noqa: E501

        :param group_id: The group_id of this IdentityLinkDto.  # noqa: E501
        :type: str
        """

        self._group_id = group_id

    @property
    def type(self):
        """Gets the type of this IdentityLinkDto.  # noqa: E501

        The type of the identity link. The value of the this property can be user-defined. The Process Engine provides three pre-defined Identity Link `type`s:  * `candidate` * `assignee` - reserved for the task assignee * `owner` - reserved for the task owner  **Note**: When adding or removing an Identity Link, the `type` property must be defined.  # noqa: E501

        :return: The type of this IdentityLinkDto.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this IdentityLinkDto.

        The type of the identity link. The value of the this property can be user-defined. The Process Engine provides three pre-defined Identity Link `type`s:  * `candidate` * `assignee` - reserved for the task assignee * `owner` - reserved for the task owner  **Note**: When adding or removing an Identity Link, the `type` property must be defined.  # noqa: E501

        :param type: The type of this IdentityLinkDto.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IdentityLinkDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IdentityLinkDto):
            return True

        return self.to_dict() != other.to_dict()
