# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.task_variable_api import TaskVariableApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestTaskVariableApi(unittest.TestCase):
    """TaskVariableApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.task_variable_api.TaskVariableApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_task_variable(self):
        """Test case for delete_task_variable

        """
        pass

    def test_get_task_variable(self):
        """Test case for get_task_variable

        """
        pass

    def test_get_task_variable_binary(self):
        """Test case for get_task_variable_binary

        """
        pass

    def test_get_task_variables(self):
        """Test case for get_task_variables

        """
        pass

    def test_modify_task_variables(self):
        """Test case for modify_task_variables

        """
        pass

    def test_put_task_variable(self):
        """Test case for put_task_variable

        """
        pass

    def test_set_binary_task_variable(self):
        """Test case for set_binary_task_variable

        """
        pass


if __name__ == '__main__':
    unittest.main()
