# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.external_task_api import ExternalTaskApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestExternalTaskApi(unittest.TestCase):
    """ExternalTaskApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.external_task_api.ExternalTaskApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_complete_external_task_resource(self):
        """Test case for complete_external_task_resource

        """
        pass

    def test_extend_lock(self):
        """Test case for extend_lock

        """
        pass

    def test_fetch_and_lock(self):
        """Test case for fetch_and_lock

        """
        pass

    def test_get_external_task(self):
        """Test case for get_external_task

        """
        pass

    def test_get_external_task_error_details(self):
        """Test case for get_external_task_error_details

        """
        pass

    def test_get_external_tasks(self):
        """Test case for get_external_tasks

        """
        pass

    def test_get_external_tasks_count(self):
        """Test case for get_external_tasks_count

        """
        pass

    def test_get_topic_names(self):
        """Test case for get_topic_names

        """
        pass

    def test_handle_external_task_bpmn_error(self):
        """Test case for handle_external_task_bpmn_error

        """
        pass

    def test_handle_failure(self):
        """Test case for handle_failure

        """
        pass

    def test_query_external_tasks(self):
        """Test case for query_external_tasks

        """
        pass

    def test_query_external_tasks_count(self):
        """Test case for query_external_tasks_count

        """
        pass

    def test_set_external_task_resource_priority(self):
        """Test case for set_external_task_resource_priority

        """
        pass

    def test_set_external_task_resource_retries(self):
        """Test case for set_external_task_resource_retries

        """
        pass

    def test_set_external_task_retries(self):
        """Test case for set_external_task_retries

        """
        pass

    def test_set_external_task_retries_async_operation(self):
        """Test case for set_external_task_retries_async_operation

        """
        pass

    def test_unlock(self):
        """Test case for unlock

        """
        pass


if __name__ == '__main__':
    unittest.main()
