# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class CompleteExternalTaskDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'worker_id': 'str',
        'variables': 'dict(str, VariableValueDto)',
        'local_variables': 'dict(str, VariableValueDto)'
    }

    attribute_map = {
        'worker_id': 'workerId',
        'variables': 'variables',
        'local_variables': 'localVariables'
    }

    def __init__(self, worker_id=None, variables=None, local_variables=None, local_vars_configuration=None):  # noqa: E501
        """CompleteExternalTaskDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._worker_id = None
        self._variables = None
        self._local_variables = None
        self.discriminator = None

        if worker_id is not None:
            self.worker_id = worker_id
        if variables is not None:
            self.variables = variables
        if local_variables is not None:
            self.local_variables = local_variables

    @property
    def worker_id(self):
        """Gets the worker_id of this CompleteExternalTaskDto.  # noqa: E501

        The id of the worker that completes the task. Must match the id of the worker who has most recently locked the task.  # noqa: E501

        :return: The worker_id of this CompleteExternalTaskDto.  # noqa: E501
        :rtype: str
        """
        return self._worker_id

    @worker_id.setter
    def worker_id(self, worker_id):
        """Sets the worker_id of this CompleteExternalTaskDto.

        The id of the worker that completes the task. Must match the id of the worker who has most recently locked the task.  # noqa: E501

        :param worker_id: The worker_id of this CompleteExternalTaskDto.  # noqa: E501
        :type: str
        """

        self._worker_id = worker_id

    @property
    def variables(self):
        """Gets the variables of this CompleteExternalTaskDto.  # noqa: E501

        A JSON object containing variable key-value pairs. Each key is a variable name and each value a JSON variable value object with the following properties:  # noqa: E501

        :return: The variables of this CompleteExternalTaskDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """Sets the variables of this CompleteExternalTaskDto.

        A JSON object containing variable key-value pairs. Each key is a variable name and each value a JSON variable value object with the following properties:  # noqa: E501

        :param variables: The variables of this CompleteExternalTaskDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._variables = variables

    @property
    def local_variables(self):
        """Gets the local_variables of this CompleteExternalTaskDto.  # noqa: E501

        A JSON object containing local variable key-value pairs. Local variables are set only in the scope of external task. Each key is a variable name and each value a JSON variable value object with the following properties:  # noqa: E501

        :return: The local_variables of this CompleteExternalTaskDto.  # noqa: E501
        :rtype: dict(str, VariableValueDto)
        """
        return self._local_variables

    @local_variables.setter
    def local_variables(self, local_variables):
        """Sets the local_variables of this CompleteExternalTaskDto.

        A JSON object containing local variable key-value pairs. Local variables are set only in the scope of external task. Each key is a variable name and each value a JSON variable value object with the following properties:  # noqa: E501

        :param local_variables: The local_variables of this CompleteExternalTaskDto.  # noqa: E501
        :type: dict(str, VariableValueDto)
        """

        self._local_variables = local_variables

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CompleteExternalTaskDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CompleteExternalTaskDto):
            return True

        return self.to_dict() != other.to_dict()
