# coding: utf-8

# flake8: noqa
"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from generic_camunda_client.models.abstract_set_removal_time_dto import AbstractSetRemovalTimeDto
from generic_camunda_client.models.activity_instance_dto import ActivityInstanceDto
from generic_camunda_client.models.activity_instance_incident_dto import ActivityInstanceIncidentDto
from generic_camunda_client.models.activity_statistics_result_dto import ActivityStatisticsResultDto
from generic_camunda_client.models.atom_link import AtomLink
from generic_camunda_client.models.attachment_dto import AttachmentDto
from generic_camunda_client.models.attachment_dto_all_of import AttachmentDtoAllOf
from generic_camunda_client.models.authorization_exception_dto import AuthorizationExceptionDto
from generic_camunda_client.models.authorization_exception_dto_all_of import AuthorizationExceptionDtoAllOf
from generic_camunda_client.models.batch_dto import BatchDto
from generic_camunda_client.models.case_definition_dto import CaseDefinitionDto
from generic_camunda_client.models.comment_dto import CommentDto
from generic_camunda_client.models.comment_dto_all_of import CommentDtoAllOf
from generic_camunda_client.models.complete_external_task_dto import CompleteExternalTaskDto
from generic_camunda_client.models.complete_task_dto import CompleteTaskDto
from generic_camunda_client.models.correlation_message_dto import CorrelationMessageDto
from generic_camunda_client.models.count_result_dto import CountResultDto
from generic_camunda_client.models.decision_definition_dto import DecisionDefinitionDto
from generic_camunda_client.models.decision_requirements_definition_dto import DecisionRequirementsDefinitionDto
from generic_camunda_client.models.delete_historic_process_instances_dto import DeleteHistoricProcessInstancesDto
from generic_camunda_client.models.delete_process_instances_dto import DeleteProcessInstancesDto
from generic_camunda_client.models.deployment_dto import DeploymentDto
from generic_camunda_client.models.deployment_dto_all_of import DeploymentDtoAllOf
from generic_camunda_client.models.deployment_resource_dto import DeploymentResourceDto
from generic_camunda_client.models.deployment_with_definitions_dto import DeploymentWithDefinitionsDto
from generic_camunda_client.models.deployment_with_definitions_dto_all_of import DeploymentWithDefinitionsDtoAllOf
from generic_camunda_client.models.duration_report_result_dto import DurationReportResultDto
from generic_camunda_client.models.evaluation_condition_dto import EvaluationConditionDto
from generic_camunda_client.models.event_subscription_dto import EventSubscriptionDto
from generic_camunda_client.models.event_subscription_query_dto import EventSubscriptionQueryDto
from generic_camunda_client.models.event_subscription_query_dto_sorting import EventSubscriptionQueryDtoSorting
from generic_camunda_client.models.exception_dto import ExceptionDto
from generic_camunda_client.models.execution_dto import ExecutionDto
from generic_camunda_client.models.extend_lock_on_external_task_dto import ExtendLockOnExternalTaskDto
from generic_camunda_client.models.external_task_bpmn_error import ExternalTaskBpmnError
from generic_camunda_client.models.external_task_bpmn_error_all_of import ExternalTaskBpmnErrorAllOf
from generic_camunda_client.models.external_task_dto import ExternalTaskDto
from generic_camunda_client.models.external_task_failure_dto import ExternalTaskFailureDto
from generic_camunda_client.models.external_task_query_dto import ExternalTaskQueryDto
from generic_camunda_client.models.external_task_query_dto_sorting import ExternalTaskQueryDtoSorting
from generic_camunda_client.models.fetch_external_task_topic_dto import FetchExternalTaskTopicDto
from generic_camunda_client.models.fetch_external_tasks_dto import FetchExternalTasksDto
from generic_camunda_client.models.form_dto import FormDto
from generic_camunda_client.models.historic_activity_instance_dto import HistoricActivityInstanceDto
from generic_camunda_client.models.historic_activity_instance_query_dto import HistoricActivityInstanceQueryDto
from generic_camunda_client.models.historic_activity_instance_query_dto_sorting import HistoricActivityInstanceQueryDtoSorting
from generic_camunda_client.models.historic_process_instance_dto import HistoricProcessInstanceDto
from generic_camunda_client.models.historic_process_instance_query_dto import HistoricProcessInstanceQueryDto
from generic_camunda_client.models.historic_process_instance_query_dto_sorting import HistoricProcessInstanceQueryDtoSorting
from generic_camunda_client.models.history_time_to_live_dto import HistoryTimeToLiveDto
from generic_camunda_client.models.identity_link_dto import IdentityLinkDto
from generic_camunda_client.models.incident_dto import IncidentDto
from generic_camunda_client.models.incident_statistics_result_dto import IncidentStatisticsResultDto
from generic_camunda_client.models.linkable_dto import LinkableDto
from generic_camunda_client.models.locked_external_task_dto import LockedExternalTaskDto
from generic_camunda_client.models.message_correlation_result_with_variable_dto import MessageCorrelationResultWithVariableDto
from generic_camunda_client.models.metrics_interval_result_dto import MetricsIntervalResultDto
from generic_camunda_client.models.metrics_result_dto import MetricsResultDto
from generic_camunda_client.models.missing_authorization_dto import MissingAuthorizationDto
from generic_camunda_client.models.multi_form_attachment_dto import MultiFormAttachmentDto
from generic_camunda_client.models.multi_form_deployment_dto import MultiFormDeploymentDto
from generic_camunda_client.models.multi_form_variable_binary_dto import MultiFormVariableBinaryDto
from generic_camunda_client.models.parse_exception_dto import ParseExceptionDto
from generic_camunda_client.models.parse_exception_dto_all_of import ParseExceptionDtoAllOf
from generic_camunda_client.models.patch_variables_dto import PatchVariablesDto
from generic_camunda_client.models.priority_dto import PriorityDto
from generic_camunda_client.models.problem_dto import ProblemDto
from generic_camunda_client.models.process_definition_diagram_dto import ProcessDefinitionDiagramDto
from generic_camunda_client.models.process_definition_dto import ProcessDefinitionDto
from generic_camunda_client.models.process_definition_statistics_result_dto import ProcessDefinitionStatisticsResultDto
from generic_camunda_client.models.process_definition_suspension_state_dto import ProcessDefinitionSuspensionStateDto
from generic_camunda_client.models.process_engine_dto import ProcessEngineDto
from generic_camunda_client.models.process_instance_dto import ProcessInstanceDto
from generic_camunda_client.models.process_instance_dto_all_of import ProcessInstanceDtoAllOf
from generic_camunda_client.models.process_instance_modification_dto import ProcessInstanceModificationDto
from generic_camunda_client.models.process_instance_modification_instruction_dto import ProcessInstanceModificationInstructionDto
from generic_camunda_client.models.process_instance_query_dto import ProcessInstanceQueryDto
from generic_camunda_client.models.process_instance_query_dto_sorting import ProcessInstanceQueryDtoSorting
from generic_camunda_client.models.process_instance_suspension_state_async_dto import ProcessInstanceSuspensionStateAsyncDto
from generic_camunda_client.models.process_instance_suspension_state_dto import ProcessInstanceSuspensionStateDto
from generic_camunda_client.models.process_instance_with_variables_dto import ProcessInstanceWithVariablesDto
from generic_camunda_client.models.process_instance_with_variables_dto_all_of import ProcessInstanceWithVariablesDtoAllOf
from generic_camunda_client.models.redeployment_dto import RedeploymentDto
from generic_camunda_client.models.resource_options_dto import ResourceOptionsDto
from generic_camunda_client.models.resource_report_dto import ResourceReportDto
from generic_camunda_client.models.restart_process_instance_dto import RestartProcessInstanceDto
from generic_camunda_client.models.restart_process_instance_modification_instruction_dto import RestartProcessInstanceModificationInstructionDto
from generic_camunda_client.models.retries_dto import RetriesDto
from generic_camunda_client.models.schema_log_entry_dto import SchemaLogEntryDto
from generic_camunda_client.models.schema_log_query_dto import SchemaLogQueryDto
from generic_camunda_client.models.schema_log_query_dto_sorting import SchemaLogQueryDtoSorting
from generic_camunda_client.models.set_job_retries_by_process_dto import SetJobRetriesByProcessDto
from generic_camunda_client.models.set_removal_time_to_historic_process_instances_dto import SetRemovalTimeToHistoricProcessInstancesDto
from generic_camunda_client.models.set_removal_time_to_historic_process_instances_dto_all_of import SetRemovalTimeToHistoricProcessInstancesDtoAllOf
from generic_camunda_client.models.set_retries_for_external_tasks_dto import SetRetriesForExternalTasksDto
from generic_camunda_client.models.set_variables_async_dto import SetVariablesAsyncDto
from generic_camunda_client.models.signal_dto import SignalDto
from generic_camunda_client.models.sort_task_query_parameters_dto import SortTaskQueryParametersDto
from generic_camunda_client.models.start_process_instance_dto import StartProcessInstanceDto
from generic_camunda_client.models.start_process_instance_form_dto import StartProcessInstanceFormDto
from generic_camunda_client.models.suspension_state_dto import SuspensionStateDto
from generic_camunda_client.models.task_bpmn_error_dto import TaskBpmnErrorDto
from generic_camunda_client.models.task_dto import TaskDto
from generic_camunda_client.models.task_escalation_dto import TaskEscalationDto
from generic_camunda_client.models.task_query_dto import TaskQueryDto
from generic_camunda_client.models.task_query_dto_sorting import TaskQueryDtoSorting
from generic_camunda_client.models.telemetry_configuration_dto import TelemetryConfigurationDto
from generic_camunda_client.models.transition_instance_dto import TransitionInstanceDto
from generic_camunda_client.models.trigger_variable_value_dto import TriggerVariableValueDto
from generic_camunda_client.models.trigger_variable_value_dto_all_of import TriggerVariableValueDtoAllOf
from generic_camunda_client.models.user_credentials_dto import UserCredentialsDto
from generic_camunda_client.models.user_dto import UserDto
from generic_camunda_client.models.user_id_dto import UserIdDto
from generic_camunda_client.models.user_profile_dto import UserProfileDto
from generic_camunda_client.models.variable_query_parameter_dto import VariableQueryParameterDto
from generic_camunda_client.models.variable_value_dto import VariableValueDto
from generic_camunda_client.models.version_dto import VersionDto
