# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from generic_camunda_client.configuration import Configuration


class ProcessInstanceModificationDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'skip_custom_listeners': 'bool',
        'skip_io_mappings': 'bool',
        'instructions': 'list[ProcessInstanceModificationInstructionDto]',
        'annotation': 'str'
    }

    attribute_map = {
        'skip_custom_listeners': 'skipCustomListeners',
        'skip_io_mappings': 'skipIoMappings',
        'instructions': 'instructions',
        'annotation': 'annotation'
    }

    def __init__(self, skip_custom_listeners=None, skip_io_mappings=None, instructions=None, annotation=None, local_vars_configuration=None):  # noqa: E501
        """ProcessInstanceModificationDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._skip_custom_listeners = None
        self._skip_io_mappings = None
        self._instructions = None
        self._annotation = None
        self.discriminator = None

        self.skip_custom_listeners = skip_custom_listeners
        self.skip_io_mappings = skip_io_mappings
        if instructions is not None:
            self.instructions = instructions
        if annotation is not None:
            self.annotation = annotation

    @property
    def skip_custom_listeners(self):
        """Gets the skip_custom_listeners of this ProcessInstanceModificationDto.  # noqa: E501

        Skip execution listener invocation for activities that are started or ended as part of this request.  # noqa: E501

        :return: The skip_custom_listeners of this ProcessInstanceModificationDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_custom_listeners

    @skip_custom_listeners.setter
    def skip_custom_listeners(self, skip_custom_listeners):
        """Sets the skip_custom_listeners of this ProcessInstanceModificationDto.

        Skip execution listener invocation for activities that are started or ended as part of this request.  # noqa: E501

        :param skip_custom_listeners: The skip_custom_listeners of this ProcessInstanceModificationDto.  # noqa: E501
        :type: bool
        """

        self._skip_custom_listeners = skip_custom_listeners

    @property
    def skip_io_mappings(self):
        """Gets the skip_io_mappings of this ProcessInstanceModificationDto.  # noqa: E501

        Skip execution of [input/output variable mappings](https://docs.camunda.org/manual/7.14/user-guide/process-engine/variables/#input-output-variable-mapping) for activities that are started or ended as part of this request.  # noqa: E501

        :return: The skip_io_mappings of this ProcessInstanceModificationDto.  # noqa: E501
        :rtype: bool
        """
        return self._skip_io_mappings

    @skip_io_mappings.setter
    def skip_io_mappings(self, skip_io_mappings):
        """Sets the skip_io_mappings of this ProcessInstanceModificationDto.

        Skip execution of [input/output variable mappings](https://docs.camunda.org/manual/7.14/user-guide/process-engine/variables/#input-output-variable-mapping) for activities that are started or ended as part of this request.  # noqa: E501

        :param skip_io_mappings: The skip_io_mappings of this ProcessInstanceModificationDto.  # noqa: E501
        :type: bool
        """

        self._skip_io_mappings = skip_io_mappings

    @property
    def instructions(self):
        """Gets the instructions of this ProcessInstanceModificationDto.  # noqa: E501

        JSON array of modification instructions. The instructions are executed in the order they are in.  # noqa: E501

        :return: The instructions of this ProcessInstanceModificationDto.  # noqa: E501
        :rtype: list[ProcessInstanceModificationInstructionDto]
        """
        return self._instructions

    @instructions.setter
    def instructions(self, instructions):
        """Sets the instructions of this ProcessInstanceModificationDto.

        JSON array of modification instructions. The instructions are executed in the order they are in.  # noqa: E501

        :param instructions: The instructions of this ProcessInstanceModificationDto.  # noqa: E501
        :type: list[ProcessInstanceModificationInstructionDto]
        """

        self._instructions = instructions

    @property
    def annotation(self):
        """Gets the annotation of this ProcessInstanceModificationDto.  # noqa: E501

        An arbitrary text annotation set by a user for auditing reasons.  # noqa: E501

        :return: The annotation of this ProcessInstanceModificationDto.  # noqa: E501
        :rtype: str
        """
        return self._annotation

    @annotation.setter
    def annotation(self, annotation):
        """Sets the annotation of this ProcessInstanceModificationDto.

        An arbitrary text annotation set by a user for auditing reasons.  # noqa: E501

        :param annotation: The annotation of this ProcessInstanceModificationDto.  # noqa: E501
        :type: str
        """

        self._annotation = annotation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProcessInstanceModificationDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProcessInstanceModificationDto):
            return True

        return self.to_dict() != other.to_dict()
