# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.external_task_dto import ExternalTaskDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestExternalTaskDto(unittest.TestCase):
    """ExternalTaskDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ExternalTaskDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.external_task_dto.ExternalTaskDto()  # noqa: E501
        if include_optional :
            return ExternalTaskDto(
                activity_id = '0', 
                activity_instance_id = '0', 
                error_message = '0', 
                execution_id = '0', 
                id = '0', 
                lock_expiration_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                process_definition_id = '0', 
                process_definition_key = '0', 
                process_definition_version_tag = '0', 
                process_instance_id = '0', 
                tenant_id = '0', 
                retries = 56, 
                suspended = True, 
                worker_id = '0', 
                topic_name = '0', 
                priority = 56, 
                business_key = '0'
            )
        else :
            return ExternalTaskDto(
        )

    def testExternalTaskDto(self):
        """Test ExternalTaskDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
