# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.incident_api import IncidentApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestIncidentApi(unittest.TestCase):
    """IncidentApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.incident_api.IncidentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_incident(self):
        """Test case for get_incident

        Get Incident  # noqa: E501
        """
        pass

    def test_get_incidents(self):
        """Test case for get_incidents

        Get List  # noqa: E501
        """
        pass

    def test_get_incidents_count(self):
        """Test case for get_incidents_count

        Get List Count  # noqa: E501
        """
        pass

    def test_resolve_incident(self):
        """Test case for resolve_incident

        Resolve Incident  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
