# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.process_definition_api import ProcessDefinitionApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestProcessDefinitionApi(unittest.TestCase):
    """ProcessDefinitionApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.process_definition_api.ProcessDefinitionApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_process_definition(self):
        """Test case for delete_process_definition

        Delete  # noqa: E501
        """
        pass

    def test_delete_process_definitions_by_key(self):
        """Test case for delete_process_definitions_by_key

        Delete By Key  # noqa: E501
        """
        pass

    def test_delete_process_definitions_by_key_and_tenant_id(self):
        """Test case for delete_process_definitions_by_key_and_tenant_id

        Delete By Key  # noqa: E501
        """
        pass

    def test_get_activity_statistics(self):
        """Test case for get_activity_statistics

        Get Activity Instance Statistics  # noqa: E501
        """
        pass

    def test_get_activity_statistics_by_process_definition_key(self):
        """Test case for get_activity_statistics_by_process_definition_key

        Get Activity Instance Statistics  # noqa: E501
        """
        pass

    def test_get_activity_statistics_by_process_definition_key_and_tenant_id(self):
        """Test case for get_activity_statistics_by_process_definition_key_and_tenant_id

        Get Activity Instance Statistics  # noqa: E501
        """
        pass

    def test_get_deployed_start_form(self):
        """Test case for get_deployed_start_form

        Get Deployed Start Form  # noqa: E501
        """
        pass

    def test_get_deployed_start_form_by_key(self):
        """Test case for get_deployed_start_form_by_key

        Get Deployed Start Form  # noqa: E501
        """
        pass

    def test_get_deployed_start_form_by_key_and_tenant_id(self):
        """Test case for get_deployed_start_form_by_key_and_tenant_id

        Get Deployed Start Form  # noqa: E501
        """
        pass

    def test_get_latest_process_definition_by_tenant_id(self):
        """Test case for get_latest_process_definition_by_tenant_id

        Get  # noqa: E501
        """
        pass

    def test_get_process_definition(self):
        """Test case for get_process_definition

        Get  # noqa: E501
        """
        pass

    def test_get_process_definition_bpmn20_xml(self):
        """Test case for get_process_definition_bpmn20_xml

        Get XML  # noqa: E501
        """
        pass

    def test_get_process_definition_bpmn20_xml_by_key(self):
        """Test case for get_process_definition_bpmn20_xml_by_key

        Get XML  # noqa: E501
        """
        pass

    def test_get_process_definition_bpmn20_xml_by_key_and_tenant_id(self):
        """Test case for get_process_definition_bpmn20_xml_by_key_and_tenant_id

        Get XML  # noqa: E501
        """
        pass

    def test_get_process_definition_by_key(self):
        """Test case for get_process_definition_by_key

        Get  # noqa: E501
        """
        pass

    def test_get_process_definition_diagram(self):
        """Test case for get_process_definition_diagram

        Get Diagram  # noqa: E501
        """
        pass

    def test_get_process_definition_diagram_by_key(self):
        """Test case for get_process_definition_diagram_by_key

        Get Diagram  # noqa: E501
        """
        pass

    def test_get_process_definition_diagram_by_key_and_tenant_id(self):
        """Test case for get_process_definition_diagram_by_key_and_tenant_id

        Get Diagram  # noqa: E501
        """
        pass

    def test_get_process_definition_statistics(self):
        """Test case for get_process_definition_statistics

        Get Process Instance Statistics  # noqa: E501
        """
        pass

    def test_get_process_definitions(self):
        """Test case for get_process_definitions

        Get List  # noqa: E501
        """
        pass

    def test_get_process_definitions_count(self):
        """Test case for get_process_definitions_count

        Get List Count  # noqa: E501
        """
        pass

    def test_get_rendered_start_form(self):
        """Test case for get_rendered_start_form

        Get Rendered Start Form  # noqa: E501
        """
        pass

    def test_get_rendered_start_form_by_key(self):
        """Test case for get_rendered_start_form_by_key

        Get Rendered Start Form  # noqa: E501
        """
        pass

    def test_get_rendered_start_form_by_key_and_tenant_id(self):
        """Test case for get_rendered_start_form_by_key_and_tenant_id

        Get Rendered Start Form  # noqa: E501
        """
        pass

    def test_get_start_form(self):
        """Test case for get_start_form

        Get Start Form Key  # noqa: E501
        """
        pass

    def test_get_start_form_by_key(self):
        """Test case for get_start_form_by_key

        Get Start Form Key  # noqa: E501
        """
        pass

    def test_get_start_form_by_key_and_tenant_id(self):
        """Test case for get_start_form_by_key_and_tenant_id

        Get Start Form Key  # noqa: E501
        """
        pass

    def test_get_start_form_variables(self):
        """Test case for get_start_form_variables

        Get Start Form Variables  # noqa: E501
        """
        pass

    def test_get_start_form_variables_by_key(self):
        """Test case for get_start_form_variables_by_key

        Get Start Form Variables  # noqa: E501
        """
        pass

    def test_get_start_form_variables_by_key_and_tenant_id(self):
        """Test case for get_start_form_variables_by_key_and_tenant_id

        Get Start Form Variables  # noqa: E501
        """
        pass

    def test_restart_process_instance(self):
        """Test case for restart_process_instance

        Restart Process Instance  # noqa: E501
        """
        pass

    def test_restart_process_instance_async_operation(self):
        """Test case for restart_process_instance_async_operation

        Restart Process Instance Async  # noqa: E501
        """
        pass

    def test_start_process_instance(self):
        """Test case for start_process_instance

        Start Instance  # noqa: E501
        """
        pass

    def test_start_process_instance_by_key(self):
        """Test case for start_process_instance_by_key

        Start Instance  # noqa: E501
        """
        pass

    def test_start_process_instance_by_key_and_tenant_id(self):
        """Test case for start_process_instance_by_key_and_tenant_id

        Start Instance  # noqa: E501
        """
        pass

    def test_submit_form(self):
        """Test case for submit_form

        Submit Start Form  # noqa: E501
        """
        pass

    def test_submit_form_by_key(self):
        """Test case for submit_form_by_key

        Submit Start Form  # noqa: E501
        """
        pass

    def test_submit_form_by_key_and_tenant_id(self):
        """Test case for submit_form_by_key_and_tenant_id

        Submit Start Form  # noqa: E501
        """
        pass

    def test_update_history_time_to_live_by_process_definition_id(self):
        """Test case for update_history_time_to_live_by_process_definition_id

        Update History Time to Live  # noqa: E501
        """
        pass

    def test_update_history_time_to_live_by_process_definition_key(self):
        """Test case for update_history_time_to_live_by_process_definition_key

        Update History Time to Live  # noqa: E501
        """
        pass

    def test_update_history_time_to_live_by_process_definition_key_and_tenant_id(self):
        """Test case for update_history_time_to_live_by_process_definition_key_and_tenant_id

        Update History Time to Live  # noqa: E501
        """
        pass

    def test_update_process_definition_suspension_state(self):
        """Test case for update_process_definition_suspension_state

        Activate/Suspend By Key  # noqa: E501
        """
        pass

    def test_update_process_definition_suspension_state_by_id(self):
        """Test case for update_process_definition_suspension_state_by_id

        Activate/Suspend By Id  # noqa: E501
        """
        pass

    def test_update_process_definition_suspension_state_by_key(self):
        """Test case for update_process_definition_suspension_state_by_key

        Activate/Suspend by Id  # noqa: E501
        """
        pass

    def test_update_process_definition_suspension_state_by_key_and_tenant_id(self):
        """Test case for update_process_definition_suspension_state_by_key_and_tenant_id

        Activate/Suspend by Id  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
