# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.process_instance_modification_instruction_dto import ProcessInstanceModificationInstructionDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestProcessInstanceModificationInstructionDto(unittest.TestCase):
    """ProcessInstanceModificationInstructionDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProcessInstanceModificationInstructionDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.process_instance_modification_instruction_dto.ProcessInstanceModificationInstructionDto()  # noqa: E501
        if include_optional :
            return ProcessInstanceModificationInstructionDto(
                type = 'cancel', 
                variables = null, 
                activity_id = '0', 
                transition_id = '0', 
                activity_instance_id = '0', 
                transition_instance_id = '0', 
                ancestor_activity_instance_id = '0', 
                cancel_current_active_activity_instances = True
            )
        else :
            return ProcessInstanceModificationInstructionDto(
                type = 'cancel',
        )

    def testProcessInstanceModificationInstructionDto(self):
        """Test ProcessInstanceModificationInstructionDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
