# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import generic_camunda_client
from generic_camunda_client.models.attachment_dto import AttachmentDto  # noqa: E501
from generic_camunda_client.rest import ApiException

class TestAttachmentDto(unittest.TestCase):
    """AttachmentDto unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AttachmentDto
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = generic_camunda_client.models.attachment_dto.AttachmentDto()  # noqa: E501
        if include_optional :
            return AttachmentDto(
                id = '0', 
                name = '0', 
                description = '0', 
                task_id = '0', 
                type = '0', 
                url = '0', 
                create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                removal_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                root_process_instance_id = '0', 
                links = [
                    generic_camunda_client.models.atom_link.AtomLink(
                        rel = '0', 
                        href = '0', 
                        method = '0', )
                    ]
            )
        else :
            return AttachmentDto(
        )

    def testAttachmentDto(self):
        """Test AttachmentDto"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
