# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.user_api import UserApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_available_operations(self):
        """Test case for available_operations

        Options  # noqa: E501
        """
        pass

    def test_available_user_operations(self):
        """Test case for available_user_operations

        Options  # noqa: E501
        """
        pass

    def test_create_user(self):
        """Test case for create_user

        Create  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete  # noqa: E501
        """
        pass

    def test_get_user_count(self):
        """Test case for get_user_count

        Get List Count  # noqa: E501
        """
        pass

    def test_get_user_profile(self):
        """Test case for get_user_profile

        Get Profile  # noqa: E501
        """
        pass

    def test_get_users(self):
        """Test case for get_users

        Get List  # noqa: E501
        """
        pass

    def test_unlock_user(self):
        """Test case for unlock_user

        Unlock User  # noqa: E501
        """
        pass

    def test_update_credentials(self):
        """Test case for update_credentials

        Update Credentials  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
