# coding: utf-8

"""
    Camunda BPM REST API

    OpenApi Spec for Camunda BPM REST API.  # noqa: E501

    The version of the OpenAPI document: 7.14.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import generic_camunda_client
from generic_camunda_client.api.process_instance_api import ProcessInstanceApi  # noqa: E501
from generic_camunda_client.rest import ApiException


class TestProcessInstanceApi(unittest.TestCase):
    """ProcessInstanceApi unit test stubs"""

    def setUp(self):
        self.api = generic_camunda_client.api.process_instance_api.ProcessInstanceApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_async_historic_query_based(self):
        """Test case for delete_async_historic_query_based

        """
        pass

    def test_delete_process_instance(self):
        """Test case for delete_process_instance

        """
        pass

    def test_delete_process_instance_variable(self):
        """Test case for delete_process_instance_variable

        """
        pass

    def test_delete_process_instances_async_operation(self):
        """Test case for delete_process_instances_async_operation

        """
        pass

    def test_get_activity_instance_tree(self):
        """Test case for get_activity_instance_tree

        """
        pass

    def test_get_process_instance(self):
        """Test case for get_process_instance

        Get Process Instance  # noqa: E501
        """
        pass

    def test_get_process_instance_variable(self):
        """Test case for get_process_instance_variable

        """
        pass

    def test_get_process_instance_variable_binary(self):
        """Test case for get_process_instance_variable_binary

        """
        pass

    def test_get_process_instance_variables(self):
        """Test case for get_process_instance_variables

        """
        pass

    def test_get_process_instances(self):
        """Test case for get_process_instances

        """
        pass

    def test_get_process_instances_count(self):
        """Test case for get_process_instances_count

        """
        pass

    def test_modify_process_instance(self):
        """Test case for modify_process_instance

        """
        pass

    def test_modify_process_instance_async_operation(self):
        """Test case for modify_process_instance_async_operation

        """
        pass

    def test_modify_process_instance_variables(self):
        """Test case for modify_process_instance_variables

        """
        pass

    def test_query_process_instances(self):
        """Test case for query_process_instances

        """
        pass

    def test_query_process_instances_count(self):
        """Test case for query_process_instances_count

        """
        pass

    def test_set_process_instance_variable(self):
        """Test case for set_process_instance_variable

        """
        pass

    def test_set_process_instance_variable_binary(self):
        """Test case for set_process_instance_variable_binary

        """
        pass

    def test_set_retries_by_process(self):
        """Test case for set_retries_by_process

        """
        pass

    def test_set_retries_by_process_historic_query_based(self):
        """Test case for set_retries_by_process_historic_query_based

        """
        pass

    def test_set_variables_async_operation(self):
        """Test case for set_variables_async_operation

        """
        pass

    def test_update_suspension_state(self):
        """Test case for update_suspension_state

        """
        pass

    def test_update_suspension_state_async_operation(self):
        """Test case for update_suspension_state_async_operation

        """
        pass

    def test_update_suspension_state_by_id(self):
        """Test case for update_suspension_state_by_id

        """
        pass


if __name__ == '__main__':
    unittest.main()
